# Lattice FPGA Modules

The {py:mod}`torii.lib.vendor.lattice` module provides wrapper instances for useful Lattice FPGA blocks.

## iCE40 Blocks

```{eval-rst}

.. autoclass:: torii.lib.vendor.lattice.ice40.ice40Warmboot

```
